@@ -761,7 +761,10 @@ def create_salesforce_contact(profile):
                     'MailingCity':profile.city,
                     'MailingState':profile.state,
                     'MailingCountry':profile.country,
-                    'MailingPostalCode':profile.zipcode})
+                    'MailingPostalCode':profile.zipcode,
+                    'Company_Name__c': profile.company,
+                    'Title': profile.position_title
+                    })
                 
                 profile.sf_contact_id = contact['id']
                 profile.save()
@@ -817,3 +820,12 @@ def extract_pdf(fp):
     retstr.close()
 
     return mystr
+
+
+def normalize_field_names(fieldnames):
+    for i in range(0, len(fieldnames)):
+        # clean up the fieldnames
+        # ex: change First Name to first_name
+        fieldnames[i] = fieldnames[i].lower().replace(' ', '_')
+
+    return fieldnames
