@@ -2,14 +2,17 @@ from datetime import datetime, timedelta
 from django.utils.translation import ugettext_lazy as _
 from django import forms
 
-from .models import EventLog
 from tendenci.core.base.fields import SplitDateTimeField
 from form_utils.forms import BetterForm
 
+from .models import EventLog
+
 INITIAL_START_DT = datetime.now() - timedelta(weeks=4)
 INITIAL_END_DT = datetime.now()
-ACTION_CHOICES = [(i, i) for i in EventLog.objects.values_list('action', flat=True).distinct().order_by('action')]
-ACTION_CHOICES = [('','---------------')] + ACTION_CHOICES
+REQUEST_CHOICES = [('all', 'ALL',), ('post', 'POST',), ('get', 'GET',)]
+APP_CHOICES = [(i, i) for i in EventLog.objects.values_list('application', flat=True).distinct().order_by('application')]
+APP_CHOICES = [('','---------------')] + APP_CHOICES
+
 
 class EventsFilterForm(forms.Form):
     event_id = forms.IntegerField(required=False)
@@ -19,14 +22,10 @@ class EventsFilterForm(forms.Form):
 
     def process_filter(self, queryset):
         cd = self.cleaned_data
-        if cd['event_id']:
-            queryset = queryset.filter(event_id=cd['event_id'])
         if cd['ip']:
             queryset = queryset.filter(user_ip_address=cd['ip'])
         if cd['user_id']:
             queryset = queryset.filter(user__pk=cd['user_id'])
-        if cd['session_id']:
-            queryset = queryset.filter(session_id=cd['session_id'])
         return queryset
 
 
@@ -36,6 +35,7 @@ class EventLogSearchForm(BetterForm):
         initial=INITIAL_START_DT,
         required=False
     )
+
     end_dt = SplitDateTimeField(
         label=_('End Date/Time'),
         initial=INITIAL_END_DT,
@@ -43,33 +43,41 @@ class EventLogSearchForm(BetterForm):
     )
     request_method = forms.ChoiceField(
         required=False,
-        choices=(('all', 'ALL',), ('post', 'POST',), ('get', 'GET',))
+        choices=REQUEST_CHOICES,
+        help_text='GET = whether a page/item was viewed. POST = an item was edited or added'
     )
-    event_id = forms.IntegerField(required=False)
-    source = forms.CharField(required=False)
-    object_id = forms.CharField(required=False)
+
+    object_id = forms.CharField(
+        required=False,
+        help_text="This is the ID Tendenci uses for all objects. "
+        "This is the number you sometimes see in URLs. For example, "
+        "for the event at http://tendenci.com/events/173/, the object ID is 173."
+    )
+
     user_ip_address = forms.CharField(required=False)
     user_id = forms.IntegerField(required=False)
     user_name = forms.CharField(required=False)
-    session_id = forms.CharField(required=False)
-    application = forms.CharField(required=False)
-    action = forms.ChoiceField(
-      required=False,
-      choices=ACTION_CHOICES
-      )
+
+    application = forms.ChoiceField(
+        required=False,
+        choices=APP_CHOICES,
+        help_text="These are the different modules like Pages or Articles."
+    )
+
+    action = forms.CharField(
+        required=False,
+        help_text="These are the actions within the python commands at view.py. "
+        "Some examples of actions are search and edit, for example.")
 
     class Meta:
         fields = (
             'start_dt',
             'end_dt',
             'request_method',
-            'event_id',
-            'source',
             'object_id'
             'user_ip_address',
             'user_id',
             'user_name',
-            'session_id',
             'application',
             'action',
             )
@@ -79,7 +87,6 @@ class EventLogSearchForm(BetterForm):
               'fields': ['start_dt',
                          'end_dt',
                          'request_method',
-                         'event_id'
                          ],
               'legend': ''
               }),
@@ -88,8 +95,6 @@ class EventLogSearchForm(BetterForm):
               'fields': ['user_id',
                          'user_name',
                          'user_ip_address',
-                         'session_id',
-                         'source',
                          'object_id',
                          'application',
                          'action'
